package com.blogspot.lifeinide.mule.integration.spring3mule2;

import java.io.IOException;

import org.mule.api.MuleContext;
import org.mule.api.registry.Registry;
import org.mule.config.ConfigResource;
import org.mule.config.spring.MissingParserProblemReporter;
import org.mule.config.spring.MuleApplicationContext;
import org.mule.config.spring.MuleBeanDefinitionDocumentReader;
import org.mule.util.ClassUtils;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.support.DefaultListableBeanFactory;
import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
import org.springframework.context.ApplicationContext;
import org.springframework.core.io.Resource;

/**
 * Uses Spring 3 compatible {@link Spring3MuleBeanDefinitionDocumentReader}
 * 
 * @author l0co@wp.pl
 */
public class Spring3MuleApplicationContext extends MuleApplicationContext {

	public Spring3MuleApplicationContext(MuleContext muleContext, Registry registry,
			ConfigResource[] configResources, ApplicationContext parent) {
		super(muleContext, registry, configResources, parent);
	}

	public Spring3MuleApplicationContext(MuleContext muleContext, Registry registry,
			ConfigResource[] configResources, boolean refresh) throws BeansException {
		super(muleContext, registry, configResources, refresh);
	}

	public Spring3MuleApplicationContext(MuleContext muleContext, Registry registry,
			ConfigResource[] configResources) {
		super(muleContext, registry, configResources);
	}

	public Spring3MuleApplicationContext(MuleContext muleContext, Registry registry,
			Resource[] springResources, ApplicationContext parent) throws IOException {
		super(muleContext, registry, springResources, parent);
	}

	public Spring3MuleApplicationContext(MuleContext muleContext, Registry registry,
			Resource[] springResources, boolean refresh) throws BeansException {
		super(muleContext, registry, springResources, refresh);
	}

	public Spring3MuleApplicationContext(MuleContext muleContext, Registry registry,
			Resource[] configResources) {
		super(muleContext, registry, configResources);
	}

	protected void loadBeanDefinitions(DefaultListableBeanFactory beanFactory) throws IOException {
		XmlBeanDefinitionReader beanDefinitionReader;

		// If the migration module is on the classpath, lets use the
		// MuleBeanDefinitionReader, that allws use
		// to process Mule 1.x configuration as well as Mule 2.x.
		if (ClassUtils.isClassOnPath(LEGACY_BEAN_READER_CLASS, getClass())) {
			try {
				beanDefinitionReader = (XmlBeanDefinitionReader) ClassUtils.instanciateClass(
						LEGACY_BEAN_READER_CLASS, new Object[] { beanFactory, getConfigResources() });
			} catch (Exception e) {
				throw new RuntimeException(e);
			}
		} else {
			beanDefinitionReader = new XmlBeanDefinitionReader(beanFactory);
		}
		// hook in our custom hierarchical reader
		beanDefinitionReader.setDocumentReaderClass(Spring3MuleBeanDefinitionDocumentReader.class);
		// add error reporting
		beanDefinitionReader.setProblemReporter(new MissingParserProblemReporter());
		beanDefinitionReader.loadBeanDefinitions(getConfigResources());
		
	}
}
